==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/RangeCategorySeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CategorySeriesDescriptionMetadata } from "./CategorySeriesDescriptionMetadata";
/**
 * @hidden
 */
export let RangeCategorySeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class RangeCategorySeriesDescriptionMetadata extends Base {
        static b(a) {
            if (RangeCategorySeriesDescriptionMetadata.a == null) {
                RangeCategorySeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                RangeCategorySeriesDescriptionMetadata.c(RangeCategorySeriesDescriptionMetadata.a);
            }
            if (a.k(RangeCategorySeriesDescriptionMetadata.a)) {
                return;
            }
            a.ab(RangeCategorySeriesDescriptionMetadata.a);
        }
        static c(a) {
            CategorySeriesDescriptionMetadata.c(a);
            a.item("LowMemberPath", "String");
            a.item("HighMemberPath", "String");
        }
        static d(a) {
            RangeCategorySeriesDescriptionMetadata.b(a);
            a.ac("RangeCategorySeries", RangeCategorySeriesDescriptionMetadata.a);
        }
    }
    RangeCategorySeriesDescriptionMetadata.$t = /*@__PURE__*/ markType(RangeCategorySeriesDescriptionMetadata, 'RangeCategorySeriesDescriptionMetadata');
    RangeCategorySeriesDescriptionMetadata.a = null;
    return RangeCategorySeriesDescriptionMetadata;
})();

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm2015/lib/RangeCategorySeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CategorySeriesDescriptionMetadata } from "./CategorySeriesDescriptionMetadata";
/**
 * @hidden
 */
export let RangeCategorySeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class RangeCategorySeriesDescriptionMetadata extends Base {
        static b(a) {
            if (RangeCategorySeriesDescriptionMetadata.a == null) {
                RangeCategorySeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                RangeCategorySeriesDescriptionMetadata.c(RangeCategorySeriesDescriptionMetadata.a);
            }
            if (a.k(RangeCategorySeriesDescriptionMetadata.a)) {
                return;
            }
            a.ac(RangeCategorySeriesDescriptionMetadata.a);
        }
        static c(a) {
            CategorySeriesDescriptionMetadata.c(a);
            a.item("LowMemberPath", "String");
            a.item("HighMemberPath", "String");
            a.item("HighlightedLowMemberPath", "String");
            a.item("HighlightedHighMemberPath", "String");
        }
        static d(a) {
            RangeCategorySeriesDescriptionMetadata.b(a);
            a.ad("RangeCategorySeries", RangeCategorySeriesDescriptionMetadata.a);
        }
    }
    RangeCategorySeriesDescriptionMetadata.$t = /*@__PURE__*/ markType(RangeCategorySeriesDescriptionMetadata, 'RangeCategorySeriesDescriptionMetadata');
    RangeCategorySeriesDescriptionMetadata.a = null;
    return RangeCategorySeriesDescriptionMetadata;
})();
